* Getting started
  * [Installation](/getting-started/install.md)
  * [Polyglot Hello World Test](/getting-started/hello_world.md)
  * [Satori Playbooks](/getting-started/playbooks.md)
  * [Results](/getting-started/execution-data.md)
* [Playbooks](/playbooks/language.md)
  * [Executions](/playbooks/execution.md)
  * [Asserts](/playbooks/asserts.md)
  * [Inputs](/playbooks/inputs.md)
  * [Settings](/playbooks/settings.md)
* [Execution modes](/modes/modes.md)
  * CI
    * [GitHub](/modes/ci/github.md)
    * [GitHub Action](/modes/ci/action.md)
    * [Gitlab](/modes/ci/gitlab.md)
    * [Jenkins](/modes/ci/jenkins.md)
  * [Run](/modes/run.md)
  * [Monitor](/modes/monitor.md)
  * [Scan](/modes/scan.md)
* [Notifications](/notifications.md)
* [Repositories](/repo.md)
* [Teams](/teams.md)
